@@ -5,7 +5,7 @@
     use XML::Compile::Util qw/pack_type/;
     use List::Util qw/first/;
     use base qw(Catalyst::Model);
-    our $VERSION = '0.0.9';
+    our $VERSION = '1.1';
 
 
     __PACKAGE__->mk_accessors('transport');
@@ -39,8 +39,6 @@
             $wsdl_obj->importDefinitions($schema)
         }
 
-        $wsdl_obj->importDefinitions(NS_SOAP_ENV);
-
         my $transport = $self->config->{transport};
         my $service = $self->config->{service};
 
@@ -78,7 +76,6 @@
 
         my $name = $operation->name();
         my $style = $operation->style;
-        my $use = $operation->{input_def}{body}{use};
 
         *{$realtarget.'::'.$operation->name()} = sub {
             my $self = shift;
